Lie Algebras
============

.. toctree::
   :maxdepth: 1

   sage/algebras/lie_algebras/abelian
   sage/algebras/lie_algebras/affine_lie_algebra
   sage/algebras/lie_algebras/bch
   sage/algebras/lie_algebras/bgg_resolution
   sage/algebras/lie_algebras/bgg_dual_module
   sage/algebras/lie_algebras/center_uea
   sage/algebras/lie_algebras/classical_lie_algebra
   sage/algebras/lie_algebras/examples
   sage/algebras/lie_algebras/free_lie_algebra
   sage/algebras/lie_algebras/heisenberg
   sage/algebras/lie_algebras/lie_algebra
   sage/algebras/lie_algebras/lie_algebra_element
   sage/algebras/lie_algebras/morphism
   sage/algebras/lie_algebras/nilpotent_lie_algebra
   sage/algebras/lie_algebras/onsager
   sage/algebras/lie_algebras/poincare_birkhoff_witt
   sage/algebras/lie_algebras/quotient
   sage/algebras/lie_algebras/rank_two_heisenberg_virasoro
   sage/algebras/lie_algebras/representation
   sage/algebras/lie_algebras/structure_coefficients
   sage/algebras/lie_algebras/subalgebra
   sage/algebras/lie_algebras/symplectic_derivation
   sage/algebras/lie_algebras/verma_module
   sage/algebras/lie_algebras/virasoro

